@@ -11,6 +11,8 @@ from .presets.preset_track_points import preset_track_points
 from .presets.preset_track_side_by_side import preset_track_side_by_side
 from .presets.utils import load_config, save_config
 
+DEBUG = 0  # debug levels (0: no debug, 1: extended traceback on exception, 2: profiling)
+
 description = textwrap.dedent(
     '''\
     Generate an optical flow visualization using the available presets.
@@ -70,6 +72,9 @@ group_core.add_argument('--use-flow-colors', type=str, choices=('y', 'n'), requi
 group_core.add_argument('--subsample-ratio', type=float, required=False, metavar='[0.0..]',
                         help='Do the mean in a square of given size in pixels')
 
+group_core.add_argument('--accumulate-flow', type=str, choices=('y', 'n'), required=False,
+                        help='When calculating multiple frames, accumulate all flow vectors from the first one.')
+
 # Output
 group_output = parser.add_argument_group('output')
 group_output.add_argument('--output-type', type=str, choices=('video', 'pyplot'), required=False,
@@ -104,11 +109,19 @@ else:
 
 # execute and save
 try:
-    presets[video_type](config)
+    if DEBUG > 1:
+        import cProfile
+        cProfile.run('presets[video_type](config)', 'profile_results')
+    else:
+        presets[video_type](config)
 except Exception as exc:
     print('')
     print('/!\ An error ocurred:')
-    print('>', exc)
+    if DEBUG > 0:
+        import traceback
+        traceback.print_exc()
+    else:
+        print('>', exc)
     print('Your current configuration can be saved, edited and later loaded with --config <config-file>')
     print('')
 
