@@ -1,12 +1,19 @@
+import numpy as np
+
+from typing import Union, Tuple
+
 from .flo_data import FloData
 from .rgb_data import RGBData
 from .track_points import TrackPoints, TrackRectangles
 from .point_input import pyplot_prompt
 
 
-def flo(path, dir_first=0, dir_total=None):
+def flo(path: str, dir_first: int = 0, dir_total: int = None):
     """
         Read .flo files and process them as a list of flow data
+        Orders files by searching for the first number that appears in its name:
+        for example, if the directory contains "seq_0001.flo" and "seq_0002.flo",
+        it uses "0001" and "0002" as order keys
         Files must be encoded with the Middlebury .flo format:
         http://vision.middlebury.edu/flow/code/flow-code/README.txt
         :param path: Either a file or a directory
@@ -21,9 +28,12 @@ def flo(path, dir_first=0, dir_total=None):
     return FloData(path, extensions=('.flo'), dir_first=dir_first, dir_total=dir_total)
 
 
-def rgb(path, dir_first=0, dir_total=None):
+def rgb(path: str, dir_first: int = 0, dir_total: int = None):
     """
-        Read .png/.bmp/.jpg files and process them as a list of RGB data
+        Read .png/.bmp/.jpg/.jpeg files and process them as a list of RGB data
+        Orders files by searching for the first number that appears in its name:
+        for example, if the directory contains "seq_0001.png" and "seq_0002.png",
+        it uses "0001" and "0002" as order keys
         :param path: Either a file or a directory
         :param dir_first: If path is a directory and contains elements 0..n-1,
                             return elements from range dir_first..n-1
@@ -36,7 +46,7 @@ def rgb(path, dir_first=0, dir_total=None):
     return RGBData(path, extensions=('.png', '.bmp', '.jpg', '.jpeg'), dir_first=dir_first, dir_total=dir_total)
 
 
-def points(custom_points):
+def points(custom_points: np.ndarray):
     """
         Convert a [n, 2] ndarray with (x, y) point data for one frame
         to an object usable by filters/operators.
@@ -47,7 +57,7 @@ def points(custom_points):
     return TrackPoints(custom_points)
 
 
-def prompt_points(n, image):
+def prompt_points(n: int, image: Union[Tuple[int, int], np.ndarray]):
     """
         Prompt the user to select points on a given image
         :param n: Number of points to select
@@ -59,7 +69,7 @@ def prompt_points(n, image):
     return TrackPoints(pyplot_prompt(n, image))
 
 
-def rect(path, rect_format='x0 y0 xw yw', elem_first=0, elem_total=None):
+def rect(path, rect_format: str = 'x0 y0 xw yw', elem_first: int = 0, elem_total: int = None):
     """
         Read a file and return a list of rectangle data
         :param path: Text file, which contains one line per frame,
