@@ -7,7 +7,7 @@ def _read_image(file_path):
     """
         :param file_path: File path of image file
         :returns: [h, w, 3] ndarray where
-                    [y, x, :] = [r, g, b] components of pixel x, y
+                    [y, x, :] = (r, g, b) components of pixel x, y
     """
     return imageio.imread(file_path)
 
